aboutsummaryrefslogtreecommitdiff
path: root/lib/csapi/inviting.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/csapi/inviting.h')
-rw-r--r--lib/csapi/inviting.h72
1 files changed, 37 insertions, 35 deletions
diff --git a/lib/csapi/inviting.h b/lib/csapi/inviting.h
index 6d5d2e99..cb9d052b 100644
--- a/lib/csapi/inviting.h
+++ b/lib/csapi/inviting.h
@@ -6,40 +6,42 @@
#include "jobs/basejob.h"
+namespace Quotient {
-namespace QMatrixClient
-{
- // Operations
+/*! \brief Invite a user to participate in a particular room.
+ *
+ * *Note that there are two forms of this API, which are documented separately.
+ * This version of the API requires that the inviter knows the Matrix
+ * identifier of the invitee. The other is documented in the*
+ * [third party invites
+ * section](/client-server-api/#post_matrixclientv3roomsroomidinvite-1).
+ *
+ * This API invites a user to participate in a particular room.
+ * They do not start participating in the room until they actually join the
+ * room.
+ *
+ * Only users currently in a particular room can invite other users to
+ * join that room.
+ *
+ * If the user was invited to the room, the homeserver will append a
+ * `m.room.member` event to the room.
+ */
+class QUOTIENT_API InviteUserJob : public BaseJob {
+public:
+ /*! \brief Invite a user to participate in a particular room.
+ *
+ * \param roomId
+ * The room identifier (not alias) to which to invite the user.
+ *
+ * \param userId
+ * The fully qualified user ID of the invitee.
+ *
+ * \param reason
+ * Optional reason to be included as the `reason` on the subsequent
+ * membership event.
+ */
+ explicit InviteUserJob(const QString& roomId, const QString& userId,
+ const QString& reason = {});
+};
- /// Invite a user to participate in a particular room.
- ///
- /// .. _invite-by-user-id-endpoint:
- ///
- /// *Note that there are two forms of this API, which are documented separately.
- /// This version of the API requires that the inviter knows the Matrix
- /// identifier of the invitee. The other is documented in the*
- /// `third party invites section`_.
- ///
- /// This API invites a user to participate in a particular room.
- /// They do not start participating in the room until they actually join the
- /// room.
- ///
- /// Only users currently in a particular room can invite other users to
- /// join that room.
- ///
- /// If the user was invited to the room, the homeserver will append a
- /// ``m.room.member`` event to the room.
- ///
- /// .. _third party invites section: `invite-by-third-party-id-endpoint`_
- class InviteUserJob : public BaseJob
- {
- public:
- /*! Invite a user to participate in a particular room.
- * \param roomId
- * The room identifier (not alias) to which to invite the user.
- * \param userId
- * The fully qualified user ID of the invitee.
- */
- explicit InviteUserJob(const QString& roomId, const QString& userId);
- };
-} // namespace QMatrixClient
+} // namespace Quotient